var path = require('path'),
	webpack = require('webpack'),
	LiveReloadPlugin = require('webpack-livereload-plugin'),
	ExtractTextPlugin = require('extract-text-webpack-plugin')


module.exports = {
	entry: {
		app: './src/index.js'
	},
	output: {
		path: path.resolve('./dist'),
		publicPath: 'dist/', //static path
		filename: '[name].js'
	},
	module: {
		// 加载器
		loaders: [
			// 使用Babel转换ES6，排除node_modules目录下的js
			{
				test: /\.js$/,
				loader: 'babel',
				exclude: /node_modules/
			}, {
				test: /\.css$/,
				loader: 'style!css!autoprefixer'
			}, {
				test: /\.(sass|scss)/,
				loader: 'style!css!autoprefixer!sass'
			}, {
				test: /\.(gif|png|jpe?g)$/,
				loaders: ['url-loader?limit=1000&name=static/imgs/[name].[ext]',
					'image-webpack?{progressive:true, optimizationLevel: 7, interlaced: false, pngquant:{quality: "65-90", speed: 4}}'
				]
			}, {
				test: /\.(html|tpl)$/,
				loader: 'html-loader'
			}, {
				test: /\.vue$/,
				loader: 'vue'
			}
		]
	},
	vue: {
		loaders: {
			css: ExtractTextPlugin.extract("css"),
			sass: ExtractTextPlugin.extract("css!sass"),
			scss: ExtractTextPlugin.extract("css!sass")
		}
	},
	babel: {
		// enable stage 0 transforms.
		// make sure to install babel-presets-stage-0
		presets: ['es2016-node5']
	},
	resolve: {
		// require时省略的扩展名，如：require('module') 不需要module.js
		extensions: ['', '.js', '.vue'],
		// // 别名
		alias: {
			components: path.join(__dirname, './src/components'),
			store: path.join(__dirname, './src/store')
		}
	},
	plugins: [
		// new LiveReloadPlugin({
		// 	// appendScriptTag: true
		// }),
		// new webpack.optimize.UglifyJsPlugin({
		// 	compress: {
		// 		warnings: false
		// 	}
		// })
		new ExtractTextPlugin("[name].css")
	]
}